# Autogenerated by Astropy-affiliated package astropy_helpers's setup.py on 2015-12-10 20:47:51.779013
from __future__ import unicode_literals
import datetime

version = "1.1"
githash = "edf9f4717124a5e87a7b27b27f3c0dfadf9b6c66"


major = 1
minor = 1
bugfix = 0

release = True
timestamp = datetime.datetime(2015, 12, 10, 20, 47, 51, 779013)
debug = False

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
